@@ -192,7 +192,8 @@ class OpenShift:
         # Discard any minor release, if present.
         return os_version.split(".", maxsplit=1)[0]
 
-    def parse_python_solver_name(self, solver_name: str) -> Dict[str, Any]:
+    @classmethod
+    def parse_python_solver_name(cls, solver_name: str) -> Dict[str, Any]:
         """Parse os and Python identifiers encoded into solver name."""
         if solver_name.startswith("solver-"):
             solver_identifiers = solver_name[len("solver-") :]
@@ -219,12 +220,13 @@ class OpenShift:
         python_version = ".".join(list(python_version))
         return {
             "os_name": parts[0],
-            "os_version": self.normalize_os_version(parts[0], parts[1]),
+            "os_version": cls.normalize_os_version(parts[0], parts[1]),
             "python_version": python_version,
         }
 
+    @classmethod
     def obtain_solver_from_runtime_environment(
-        self, runtime_environment: Dict[str, Any]
+        cls, runtime_environment: Dict[str, Any]
     ) -> Optional[str]:
         """Define solver from runtime_environment."""
         solver = None
@@ -234,7 +236,7 @@ class OpenShift:
             return solver
 
         os_name = runtime_environment["operating_system"].get("name")
-        os_version = self.normalize_os_version(
+        os_version = cls.normalize_os_version(
             operating_system.get("name"), operating_system.get("version")
         )
         python_version = runtime_environment.get("python_version")
@@ -249,7 +251,7 @@ class OpenShift:
         else:
             solver = f"solver-{os_name}-{os_version}"
 
-        self.parse_python_solver_name(solver)
+        cls.parse_python_solver_name(solver)
 
         return solver
 
@@ -769,7 +771,7 @@ class OpenShift:
             workflow_parameters["batch-size"] = specification["batch_size"]
 
         return self._schedule_workflow(
-            workflow=self.workflow_manager.submit_inspection_workflow,
+            workflow=self.workflow_manager.submit_inspection,
             parameters={
                 "template_parameters": template_parameters,
                 "workflow_parameters": workflow_parameters,
@@ -842,7 +844,38 @@ class OpenShift:
         workflow_parameters = self._assign_workflow_parameters_for_ceph()
 
         return self._schedule_workflow(
-            workflow=self.workflow_manager.submit_solver_workflow,
+            workflow=self.workflow_manager.submit_solver,
+            parameters={
+                "template_parameters": template_parameters,
+                "workflow_parameters": workflow_parameters,
+            },
+        )
+
+    def schedule_revsolver(
+        self,
+        package_name: str,
+        package_version: str,
+        *,
+        debug: bool = False,
+        job_id: Optional[str] = None,
+    ) -> Optional[str]:
+        """Schedule reverse solver."""
+        if not self.middletier_namespace:
+            raise ConfigurationError(
+                "Unable to schedule reverse solver without middletier namespace being set"
+            )
+
+        workflow_id = job_id or self.generate_id("revsolver")
+        template_parameters = {
+            "THOTH_REVSOLVER_WORKFLOW_ID": workflow_id,
+            "THOTH_REVSOLVER_PACKAGE_NAME": package_name,
+            "THOTH_REVSOLVER_PACKAGE_VERSION": package_version,
+            "THOTH_LOG_REVSOLVER": "DEBUG" if debug else "INFO",
+        }
+        workflow_parameters = self._assign_workflow_parameters_for_ceph()
+
+        return self._schedule_workflow(
+            workflow=self.workflow_manager.submit_revsolver,
             parameters={
                 "template_parameters": template_parameters,
                 "workflow_parameters": workflow_parameters,
@@ -897,7 +930,7 @@ class OpenShift:
         workflow_parameters = self._assign_workflow_parameters_for_ceph()
 
         return self._schedule_workflow(
-            workflow=self.workflow_manager.submit_package_extract_workflow,
+            workflow=self.workflow_manager.submit_package_extract,
             parameters={
                 "template_parameters": template_parameters,
                 "workflow_parameters": workflow_parameters,
@@ -1009,7 +1042,7 @@ class OpenShift:
         workflow_parameters = self._assign_workflow_parameters_for_ceph()
 
         return self._schedule_workflow(
-            workflow=self.workflow_manager.submit_dependency_monkey_workflow,
+            workflow=self.workflow_manager.submit_dependency_monkey,
             parameters={
                 "template_parameters": template_parameters,
                 "workflow_parameters": workflow_parameters,
@@ -1127,7 +1160,6 @@ class OpenShift:
         dev: bool = False,
         debug: bool = False,
         job_id: Optional[str] = None,
-        limit_latest_versions: Optional[int] = None,
         github_event_type: Optional[str] = None,
         github_check_run_id: Optional[int] = None,
         github_installation_id: Optional[int] = None,
@@ -1199,15 +1231,10 @@ class OpenShift:
         if count is not None:
             template_parameters["THOTH_ADVISER_COUNT"] = count
 
-        if limit_latest_versions is not None:
-            template_parameters[
-                "THOTH_ADVISER_LIMIT_LATEST_VERSIONS"
-            ] = limit_latest_versions
-
         workflow_parameters = self._assign_workflow_parameters_for_ceph()
 
         return self._schedule_workflow(
-            workflow=self.workflow_manager.submit_adviser_workflow,
+            workflow=self.workflow_manager.submit_adviser,
             parameters={
                 "template_parameters": template_parameters,
                 "workflow_parameters": workflow_parameters,
@@ -1260,7 +1287,7 @@ class OpenShift:
         workflow_parameters = self._assign_workflow_parameters_for_ceph()
 
         return self._schedule_workflow(
-            workflow=self.workflow_manager.submit_provenance_checker_workflow,
+            workflow=self.workflow_manager.submit_provenance_checker,
             parameters={
                 "template_parameters": template_parameters,
                 "workflow_parameters": workflow_parameters,
@@ -1293,7 +1320,7 @@ class OpenShift:
         }
 
         return self._schedule_workflow(
-            workflow=self.workflow_manager.submit_thamos_workflow,
+            workflow=self.workflow_manager.submit_thamos,
             parameters={
                 "template_parameters": template_parameters,
                 "workflow_parameters": {},
@@ -1309,7 +1336,7 @@ class OpenShift:
         template_parameters = {"WORKFLOW_ID": workflow_id, "REPOSITORY": repository}
 
         return self._schedule_workflow(
-            workflow=self.workflow_manager.submit_srcopsmetrics_workflow,
+            workflow=self.workflow_manager.submit_srcopsmetrics,
             parameters={
                 "template_parameters": template_parameters,
                 "workflow_parameters": {},
@@ -1327,69 +1354,40 @@ class OpenShift:
         }
 
         return self._schedule_workflow(
-            workflow=self.workflow_manager.submit_kebechet_workflow,
+            workflow=self.workflow_manager.submit_kebechet,
             parameters={
                 "template_parameters": template_parameters,
                 "workflow_parameters": {},
             },
         )
 
-    def schedule_si_bandit(
+    def schedule_security_indicator(
         self,
         python_package_name: str,
         python_package_version: str,
         python_package_index: str,
+        aggregation_function: str,
         *,
         job_id: Optional[str] = None,
     ) -> Optional[str]:
-        """Schedule a bandit security indicator run."""
+        """Schedule a security indicator run."""
         if not self.middletier_namespace:
             raise ConfigurationError(
-                "Unable to schedule si-bandit without middletier namespace being set"
+                "Unable to schedule security-indicator without middletier namespace being set"
             )
 
-        si_bandit_id = job_id or self.generate_id("si-bandit")
+        security_indicator_id = job_id or self.generate_id("security-indicator")
         template_parameters = {
-            "THOTH_SI_BANDIT_JOB_ID": si_bandit_id,
-            "THOTH_SI_BANDIT_PACKAGE_NAME": python_package_name,
-            "THOTH_SI_BANDIT_PACKAGE_VERSION": python_package_version,
-            "THOTH_SI_BANDIT_PACKAGE_INDEX": python_package_index,
+            "THOTH_SECURITY_INDICATORS_JOB_ID": security_indicator_id,
+            "THOTH_SECURITY_INDICATORS_PACKAGE_NAME": python_package_name,
+            "THOTH_SECURITY_INDICATORS_PACKAGE_VERSION": python_package_version,
+            "THOTH_SECURITY_INDICATORS_PACKAGE_INDEX": python_package_index,
+            "THOTH_SECURITY_INDICATORS_AGGREGATION_FUNCTION": aggregation_function,
         }
         workflow_parameters = self._assign_workflow_parameters_for_ceph()
 
         return self._schedule_workflow(
-            workflow=self.workflow_manager.submit_si_bandit_workflow,
-            parameters={
-                "template_parameters": template_parameters,
-                "workflow_parameters": workflow_parameters,
-            },
-        )
-
-    def schedule_si_cloc(
-        self,
-        python_package_name: str,
-        python_package_version: str,
-        python_package_index: str,
-        *,
-        job_id: Optional[str] = None,
-    ) -> Optional[str]:
-        """Schedule a cloc security indicator run."""
-        if not self.middletier_namespace:
-            raise ConfigurationError(
-                "Unable to schedule si-cloc without middletier namespace being set"
-            )
-
-        si_cloc_id = job_id or self.generate_id("si-cloc")
-        template_parameters = {
-            "THOTH_SI_CLOC_JOB_ID": si_cloc_id,
-            "THOTH_SI_CLOC_PACKAGE_NAME": python_package_name,
-            "THOTH_SI_CLOC_PACKAGE_VERSION": python_package_version,
-            "THOTH_SI_CLOC_PACKAGE_INDEX": python_package_index,
-        }
-        workflow_parameters = self._assign_workflow_parameters_for_ceph()
-
-        return self._schedule_workflow(
-            workflow=self.workflow_manager.submit_si_cloc_workflow,
+            workflow=self.workflow_manager.submit_security_indicator,
             parameters={
                 "template_parameters": template_parameters,
                 "workflow_parameters": workflow_parameters,
@@ -1610,6 +1608,29 @@ class OpenShift:
 
         return wf
 
+    def get_workflow_status_report(
+        self,
+        workflow_id: str,
+        label_selector: Optional[str] = None,
+        namespace: Optional[str] = None,
+    ) -> Dict[str, Optional[str]]:
+        """Get workflow status report, derived from workflow status."""
+        try:
+            wf_status = self.get_workflow_status(
+                name=workflow_id, label_selector=label_selector, namespace=namespace
+            )
+            status = {
+                "finished_at": wf_status.get("finishedAt"),
+                "reason": None,
+                "started_at": wf_status.get("startedAt"),
+                "state": wf_status.get("phase", "pending").lower(),
+            }
+        except NotFoundException as exc:
+            raise NotFoundException(
+                f"Requested status for analysis {workflow_id!r} was not found"
+            ) from exc
+        return status
+
     def get_workflow_status(
         self,
         name: Optional[str] = None,
