@@ -494,7 +494,7 @@ class WorkflowManager:
 
         return workflow_id
 
-    def submit_inspection_workflow(
+    def submit_inspection(
         self,
         template_parameters: Optional[Dict[str, str]] = None,
         workflow_parameters: Optional[Dict[str, Any]] = None,
@@ -529,7 +529,7 @@ class WorkflowManager:
 
         return workflow_id
 
-    def submit_adviser_workflow(
+    def submit_adviser(
         self,
         template_parameters: Optional[Dict[str, str]] = None,
         workflow_parameters: Optional[Dict[str, Any]] = None,
@@ -554,7 +554,7 @@ class WorkflowManager:
 
         return workflow_id
 
-    def submit_package_extract_workflow(
+    def submit_package_extract(
         self,
         template_parameters: Optional[Dict[str, str]] = None,
         workflow_parameters: Optional[Dict[str, str]] = None,
@@ -576,7 +576,7 @@ class WorkflowManager:
 
         return workflow_id
 
-    def submit_dependency_monkey_workflow(
+    def submit_dependency_monkey(
         self,
         template_parameters: Optional[Dict[str, str]] = None,
         workflow_parameters: Optional[Dict[str, Any]] = None,
@@ -601,7 +601,7 @@ class WorkflowManager:
 
         return workflow_id
 
-    def submit_provenance_checker_workflow(
+    def submit_provenance_checker(
         self,
         template_parameters: Optional[Dict[str, str]] = None,
         workflow_parameters: Optional[Dict[str, Any]] = None,
@@ -626,7 +626,7 @@ class WorkflowManager:
 
         return workflow_id
 
-    def submit_kebechet_workflow(
+    def submit_kebechet(
         self,
         template_parameters: Optional[Dict[str, str]] = None,
         workflow_parameters: Optional[Dict[str, Any]] = None,
@@ -651,7 +651,7 @@ class WorkflowManager:
 
         return workflow_id
 
-    def submit_solver_workflow(
+    def submit_solver(
         self,
         template_parameters: Optional[Dict[str, str]] = None,
         workflow_parameters: Optional[Dict[str, Any]] = None,
@@ -676,7 +676,29 @@ class WorkflowManager:
 
         return workflow_id
 
-    def submit_thamos_workflow(
+    def submit_revsolver(
+        self,
+        template_parameters: Optional[Dict[str, str]] = None,
+        workflow_parameters: Optional[Dict[str, Any]] = None,
+    ) -> Optional[str]:
+        """Submit reverse solver workflow."""
+        if not self.openshift.infra_namespace:
+            raise ConfigurationError("Infra namespace was not provided.")
+
+        if not self.openshift.middletier_namespace:
+            raise ConfigurationError("Middletier namespace was not provided.")
+
+        workflow_id: Optional[str] = self.submit_workflow_from_template(
+            self.openshift.infra_namespace,
+            label_selector="template=revsolver",
+            template_parameters=template_parameters or {},
+            workflow_parameters=workflow_parameters or {},
+            workflow_namespace=self.openshift.middletier_namespace,
+        )
+
+        return workflow_id
+
+    def submit_thamos(
         self,
         template_parameters: Optional[Dict[str, str]] = None,
         workflow_parameters: Optional[Dict[str, Any]] = None,
@@ -701,12 +723,12 @@ class WorkflowManager:
 
         return workflow_id
 
-    def submit_si_bandit_workflow(
+    def submit_security_indicator(
         self,
         template_parameters: Optional[Dict[str, str]] = None,
         workflow_parameters: Optional[Dict[str, Any]] = None,
     ) -> Optional[str]:
-        """Submit Bandit Security Indicator Workflow."""
+        """Submit Security Indicator Workflow."""
         if not self.openshift.infra_namespace:
             raise ConfigurationError("Infra namespace was not provided.")
 
@@ -718,7 +740,7 @@ class WorkflowManager:
 
         workflow_id: Optional[str] = self.submit_workflow_from_template(
             self.openshift.infra_namespace,
-            label_selector="template=si-bandit",
+            label_selector="template=security-indicators",
             template_parameters=template_parameters,
             workflow_parameters=workflow_parameters,
             workflow_namespace=self.openshift.middletier_namespace,
@@ -726,32 +748,7 @@ class WorkflowManager:
 
         return workflow_id
 
-    def submit_si_cloc_workflow(
-        self,
-        template_parameters: Optional[Dict[str, str]] = None,
-        workflow_parameters: Optional[Dict[str, Any]] = None,
-    ) -> Optional[str]:
-        """Submit CLOC Security Indicator Workflow."""
-        if not self.openshift.infra_namespace:
-            raise ConfigurationError("Infra namespace was not provided.")
-
-        if not self.openshift.middletier_namespace:
-            raise ConfigurationError("Middletier namespace was not provided.")
-
-        template_parameters = template_parameters or {}
-        workflow_parameters = workflow_parameters or {}
-
-        workflow_id: Optional[str] = self.submit_workflow_from_template(
-            self.openshift.infra_namespace,
-            label_selector="template=si-cloc",
-            template_parameters=template_parameters,
-            workflow_parameters=workflow_parameters,
-            workflow_namespace=self.openshift.middletier_namespace,
-        )
-
-        return workflow_id
-
-    def submit_srcopsmetrics_workflow(
+    def submit_srcopsmetrics(
         self,
         template_parameters: Optional[Dict[str, str]] = None,
         workflow_parameters: Optional[Dict[str, Any]] = None,
